import { SeederCollection, DeepPartial } from './common';
import { SeederDatabaseConfig } from './database';
import { BulkWriteOptions, MongoClientOptions } from 'mongodb';
import { EJSONOptions } from 'bson';
/**
 * Defines configuration for database seeding.
 */
export interface SeederConfig {
    /**
     * Database connection URI or configuration object.
     */
    database: SeederDatabaseConfig;
    /**
     * Maximum time of waiting for successful MongoDB connection in milliseconds. Ignored when `mongoClientOptions` are passed.
     */
    databaseReconnectTimeout: number;
    /**
     * Drops entire database before import.
     */
    dropDatabase: boolean;
    /**
     * Drops collection before importing it.
     */
    dropCollections: boolean;
    /**
     * Deletes all documents from every collection that is being imported.
     */
    removeAllDocuments: boolean;
    /**
     * Optional MongoDB client options.
     */
    mongoClientOptions?: MongoClientOptions;
    /**
     * Optional MongoDB collection write options.
     */
    bulkWriteOptions?: BulkWriteOptions;
}
/**
 * Stores default configuration for database seeding.
 */
export declare const defaultSeederConfig: SeederConfig;
/**
 * Merges configuration for database seeding.
 *
 * @param partial Partial config object. If not specified, returns a default config object.
 * @param previous Previous config object. If not specified, uses a default config object as a base.
 */
export declare const mergeSeederConfig: (partial?: DeepPartial<SeederConfig>, previous?: SeederConfig) => SeederConfig;
/**
 * Defines collection reading configuration.
 */
export interface SeederCollectionReadingOptions {
    /**
     * Files extensions that should be imported
     */
    extensions: string[];
    /**
     * Options for parsing EJSON files with `.json` extension
     */
    ejsonParseOptions?: EJSONOptions;
    /**
     * Optional transformer functions that can be used to modify collection data before import.
     */
    transformers: ((collection: SeederCollection) => SeederCollection)[];
}
/**
 * Stores default collection reading configuration values.
 */
export declare const defaultCollectionReadingOptions: SeederCollectionReadingOptions;
/**
 * Merges configuration for collection reading.
 *
 * @param partial Partial config object. If not specified, returns a default config object.
 * @param previous Previous config object. If not specified, uses a default config object as a base.
 */
export declare const mergeCollectionReadingOptions: (partial?: DeepPartial<SeederCollectionReadingOptions>, previous?: SeederCollectionReadingOptions) => SeederCollectionReadingOptions;
